utils
=====

.. py:currentmodule:: sinabs.utils

.. autofunction:: sinabs.utils.reset_states
.. autofunction:: sinabs.utils.zero_grad
.. autofunction:: sinabs.utils.get_activations
.. autofunction:: sinabs.utils.get_network_activations
.. autofunction:: sinabs.utils.normalize_weights
